@@ -1,5 +1,4 @@
 use std::env;
-use mtk::Error;
 
 pub fn collect() -> Vec<String> {
     env::args().collect()
@@ -19,11 +18,11 @@ pub fn get(unfixed: &str, argv: &Vec<String>) -> Result<String, ParseError> {
     let collected = argv;
     let fixed = match fix(unfixed) {
         Some(some) => some,
-        None => return Err(ParseError::new(format!("unable to fix `{}`", unfixed)))
+        None => return Err(ParseError::new(format!("unable to fix `{}`", unfixed))),
     };
 
     let mut res: Option<String> = None;
-    
+
     for arg in collected.iter() {
         if arg == &fixed {
             res = Some(arg.clone());
@@ -32,7 +31,7 @@ pub fn get(unfixed: &str, argv: &Vec<String>) -> Result<String, ParseError> {
 
     match res {
         Some(some) => Ok(some),
-        None => Err(ParseError::new("no such argument"))
+        None => Err(ParseError::new("no such argument")),
     }
 }
 
@@ -40,7 +39,7 @@ pub fn contains(unfixed: &str, argv: &Vec<String>) -> bool {
     let collected = argv;
     let fixed = match fix(unfixed) {
         Some(some) => some,
-        None => return false
+        None => return false,
     };
 
     for arg in collected.iter() {
@@ -52,22 +51,7 @@ pub fn contains(unfixed: &str, argv: &Vec<String>) -> bool {
     false
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord)]
-pub struct ParseError {
-    msg: String
-}
-
-impl Error for ParseError {
-    fn new<S: AsRef<str>>(msg: S) -> Self {
-        ParseError {
-            msg: msg.as_ref().to_string()
-        }
-    }
-
-    fn to_string(&self) -> String {
-        self.msg.clone()
-    }
-}
+pub type ParseError = mtk::Error;
 
 #[cfg(test)]
 mod tests;
